@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt_extra.c,v 1.23 2002/07/06 10:18:18 nmav Exp $ */
+/* $Id: mcrypt_extra.c,v 1.26 2002/12/17 10:53:34 nmav Exp $ */
 
 #include <libdefs.h>
 #include <bzero.h>
@@ -27,8 +27,8 @@
 int mcrypt_algorithm_module_ok(const char *file, const char *directory);
 int mcrypt_mode_module_ok(const char *file, const char *directory);
 
-void *mcrypt_dlopen(mcrypt_dlhandle *handle, const char *a_directory, const char *m_directory,
-		    const char *filename);
+void *mcrypt_dlopen(mcrypt_dlhandle * handle, const char *a_directory,
+		    const char *m_directory, const char *filename);
 
 #ifdef HAVE_READDIR_R
 # define MAXPATHLEN 256
@@ -40,7 +40,7 @@ WIN32DLL_DEFINE char *mcrypt_readdir(DIR * dirstream)
 	char *result;
 	struct dirent *ret = NULL;
 #ifdef HAVE_READDIR_R
-	struct dirent ret2[sizeof(struct dirent)+MAXPATHLEN];
+	struct dirent ret2[sizeof(struct dirent) + MAXPATHLEN];
 #endif
 
 #ifdef HAVE_READDIR_R
@@ -48,13 +48,13 @@ WIN32DLL_DEFINE char *mcrypt_readdir(DIR * dirstream)
 #else
 	ret = readdir(dirstream);
 #endif
-	if (ret==NULL) return NULL;
+	if (ret == NULL)
+		return NULL;
 
-	result = calloc(1, strlen(ret->d_name) + 1);
+	result = strdup(ret->d_name);
 	if (result == NULL) {
 		return NULL;
 	}
-	strcpy(result, ret->d_name);
 
 	return result;
 
@@ -62,41 +62,46 @@ WIN32DLL_DEFINE char *mcrypt_readdir(DIR * dirstream)
 
 extern const mcrypt_preloaded mps[];
 
-WIN32DLL_DEFINE char **mcrypt_list_algorithms(const char *libdir, int *size)
+WIN32DLL_DEFINE char **mcrypt_list_algorithms(const char *libdir,
+					      int *size)
 {
 	DIR *pdir;
 	char directory[512];
 	char *dirname;
 	char **filename = NULL, *ptr;
-	int tmpsize, i=0;
+	int tmpsize, i = 0;
 
 
 	*size = 0;
 
-	while( mps[i].name!=0 || mps[i].address!=0) {   
-		if (mps[i].name!=NULL && mps[i].address==NULL) {
-			if (mcrypt_algorithm_module_ok( mps[i].name, NULL) > 0) {
+	while (mps[i].name != 0 || mps[i].address != 0) {
+		if (mps[i].name != NULL && mps[i].address == NULL) {
+			if (mcrypt_algorithm_module_ok(mps[i].name, NULL) >
+			    0) {
 				filename =
 				    realloc(filename,
-					    ((*size) + 1) * sizeof(char *));
-				if (filename==NULL) {
+					    ((*size) +
+					     1) * sizeof(char *));
+				if (filename == NULL) {
 					goto freeall;
 				}
-				filename[*size] = strdup( mps[i].name);
-				if (filename[*size]==NULL) goto freeall;
+				filename[*size] = strdup(mps[i].name);
+				if (filename[*size] == NULL)
+					goto freeall;
 				(*size)++;
 			}
 		}
 		i++;
-	}	
+	}
 
 #ifdef USE_LTDL
 
 	if (libdir == NULL) {
-		strcpy(directory, LIBDIR);
+		strncpy(directory, LIBDIR, sizeof(directory)-1);
 	} else {
-		strcpy(directory, libdir);
+		strncpy(directory, libdir, sizeof(directory)-1);
 	}
+	directory[ sizeof(directory)-1] = 0;
 
 	pdir = opendir(directory);
 	if (pdir == NULL) {
@@ -112,47 +117,42 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(const char *libdir, int *size)
 		if (dirname != NULL) {
 			tmpsize = strlen(dirname);
 			if (tmpsize > 3) {
+
 				if (mcrypt_algorithm_module_ok
 				    (dirname, directory) > 0) {
-
-					ptr =
-					    strrchr( dirname, '.');
+					ptr = strrchr(dirname, '.');
 					if (ptr != NULL) {
 						*ptr = '\0';
 						tmpsize = strlen(dirname);
 					}
-					if (_mcrypt_search_symlist_lib( dirname)!=NULL) {
+
+					if (_mcrypt_search_symlist_lib
+					    (dirname) != NULL) {
 						free(dirname);
-						continue; /* it's already in the list,
-						           * since it's included in the lib.
-						           */
+						continue;	/* it's already in the list,
+								 * since it's included in the lib.
+								 */
 					}
+
 					filename =
 					    realloc(filename,
 						    (*size +
 						     1) * sizeof(char *));
-					if (filename==NULL) {
+					if (filename == NULL) {
 						free(dirname);
 						goto freeall;
 					}
 
-					
-					filename[*size] = (char*)
-					    calloc(1, tmpsize + 1);
-					if (filename[*size]==NULL) {
+					filename[*size] = strdup(dirname);
+					if (filename[*size] == NULL) {
 						free(dirname);
 						goto freeall;
 					}
-					strcpy(filename[*size], dirname);
-					
 					(*size)++;
 				}
 			}
 			free(dirname);
-		} else {
-			break;
-		}
-
+		} else break;
 	}
 
 
@@ -162,12 +162,12 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(const char *libdir, int *size)
 
 	return filename;
 
-	freeall:
-		for (i=0;i<(*size);i++) {
-			free(filename[i]);
-		}
-		free(filename);
-		return NULL;
+      freeall:
+	for (i = 0; i < (*size); i++) {
+		free(filename[i]);
+	}
+	free(filename);
+	return NULL;
 }
 
 WIN32DLL_DEFINE char **mcrypt_list_modes(const char *libdir, int *size)
@@ -177,35 +177,36 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(const char *libdir, int *size)
 	char *dirname;
 	char **filename = NULL, *ptr;
 	int tmpsize;
-	int i=0;
-	
+	int i = 0;
+
 	*size = 0;
-	
-	while( mps[i].name!=0 || mps[i].address!=0) {   
-		if (mps[i].name!=NULL && mps[i].address==NULL) {
-			if (mcrypt_mode_module_ok( mps[i].name, NULL) > 0) {
+
+	while (mps[i].name != 0 || mps[i].address != 0) {
+		if (mps[i].name != NULL && mps[i].address == NULL) {
+			if (mcrypt_mode_module_ok(mps[i].name, NULL) > 0) {
 				filename =
 				    realloc(filename,
-					    (*size +
-					     1) * sizeof(char *));
-				if (filename==NULL) {
+					    (*size + 1) * sizeof(char *));
+				if (filename == NULL) {
 					goto freeall;
 				}
-				filename[*size] = strdup( mps[i].name);
-				if (filename[*size]==NULL) goto freeall;
+				filename[*size] = strdup(mps[i].name);
+				if (filename[*size] == NULL)
+					goto freeall;
 				(*size)++;
 			}
 		}
 		i++;
-	}	
+	}
 
 #ifdef USE_LTDL
 
 	if (libdir == NULL) {
-		strcpy(directory, LIBDIR);
+		strncpy(directory, LIBDIR, sizeof(directory)-1);
 	} else {
-		strcpy(directory, libdir);
+		strncpy(directory, libdir, sizeof(directory)-1);
 	}
+	directory[ sizeof(directory)-1] = 0;
 
 	pdir = opendir(directory);
 	if (pdir == NULL) {
@@ -225,34 +226,32 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(const char *libdir, int *size)
 				if (mcrypt_mode_module_ok
 				    (dirname, directory) > 0) {
 
-					ptr =
-					    strrchr( dirname, '.');
+					ptr = strrchr(dirname, '.');
 					if (ptr != NULL) {
 						*ptr = '\0';
 						tmpsize = strlen(dirname);
 					}
-					if (_mcrypt_search_symlist_lib( dirname)!=NULL) {
+					if (_mcrypt_search_symlist_lib
+					    (dirname) != NULL) {
 						free(dirname);
-						continue; /* it's already in the list,
-						           * since it's included in the lib.
-						           */
+						continue;	/* it's already in the list,
+								 * since it's included in the lib.
+								 */
 					}
 					filename =
 					    realloc(filename,
 						    (*size +
 						     1) * sizeof(char *));
-					if (filename==NULL) {
+					if (filename == NULL) {
 						free(dirname);
 						goto freeall;
 					}
-					filename[*size] =
-					    calloc(1, tmpsize + 1);
-					if (filename[*size]==NULL) {
+
+					filename[*size] = strdup(dirname);
+					if (filename[*size] == NULL) {
 						free(dirname);
 						goto freeall;
 					}
-					
-					strcpy(filename[*size], dirname);
 					(*size)++;
 				}
 			}
@@ -268,12 +267,12 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(const char *libdir, int *size)
 
 	return filename;
 
-	freeall:
-		for (i=0;i<(*size);i++) {
-			free(filename[i]);
-		}
-		free(filename);
-		return NULL;
+      freeall:
+	for (i = 0; i < (*size); i++) {
+		free(filename[i]);
+	}
+	free(filename);
+	return NULL;
 }
 
 WIN32DLL_DEFINE void mcrypt_free_p(char **p, int size)
@@ -289,9 +288,9 @@ WIN32DLL_DEFINE void mcrypt_free_p(char **p, int size)
 WIN32DLL_DEFINE
     int mcrypt_algorithm_module_ok(const char *file, const char *directory)
 {
-	word32 ret;
+	word32 ret = 1;
 	mcrypt_dlhandle _handle;
-	void* rr;
+	void *rr;
 	int (*_version) (void);
 
 	if (file == NULL && directory == NULL) {
@@ -302,7 +301,6 @@ WIN32DLL_DEFINE
 		return MCRYPT_UNKNOWN_ERROR;
 	}
 
-
 	rr = mcrypt_dlopen(&_handle, directory, NULL, file);
 
 	if (!rr) {
@@ -322,6 +320,7 @@ WIN32DLL_DEFINE
 	ret = _version();
 
 	mcrypt_dlclose(_handle);
+
 	lt_dlexit();
 
 	return ret;
@@ -333,7 +332,7 @@ WIN32DLL_DEFINE
 {
 	word32 ret;
 	mcrypt_dlhandle _handle;
-	void* rr;
+	void *rr;
 	int (*_version) (void);
 
 	if (file == NULL && directory == NULL) {
@@ -370,37 +369,36 @@ WIN32DLL_DEFINE
 
 /* Taken from libgcrypt */
 
-static const char*
-parse_version_number( const char *s, int *number )
+static const char *parse_version_number(const char *s, int *number)
 {
-    int val = 0;
+	int val = 0;
 
-    if( *s == '0' && isdigit(s[1]) )
-	return NULL; /* leading zeros are not allowed */
-    for ( ; isdigit(*s); s++ ) {
-	val *= 10;
-	val += *s - '0';
-    }
-    *number = val;
-    return val < 0? NULL : s;
+	if (*s == '0' && isdigit(s[1]))
+		return NULL;	/* leading zeros are not allowed */
+	for (; isdigit(*s); s++) {
+		val *= 10;
+		val += *s - '0';
+	}
+	*number = val;
+	return val < 0 ? NULL : s;
 }
 
 
-static const char *
-parse_version_string( const char *s, int *major, int *minor, int *micro )
+static const char *parse_version_string(const char *s, int *major,
+					int *minor, int *micro)
 {
-    s = parse_version_number( s, major );
-    if( !s || *s != '.' )
-	return NULL;
-    s++;
-    s = parse_version_number( s, minor );
-    if( !s || *s != '.' )
-	return NULL;
-    s++;
-    s = parse_version_number( s, micro );
-    if( !s )
-	return NULL;
-    return s; /* patchlevel */
+	s = parse_version_number(s, major);
+	if (!s || *s != '.')
+		return NULL;
+	s++;
+	s = parse_version_number(s, minor);
+	if (!s || *s != '.')
+		return NULL;
+	s++;
+	s = parse_version_number(s, micro);
+	if (!s)
+		return NULL;
+	return s;		/* patchlevel */
 }
 
 /****************
@@ -409,34 +407,33 @@ parse_version_string( const char *s, int *major, int *minor, int *micro )
  * satisfied.  If a NULL is passed to this function, no check is done,
  * but the version string is simply returned.
  */
-const char *
-mcrypt_check_version( const char *req_version )
+const char *mcrypt_check_version(const char *req_version)
 {
-    const char *ver = VERSION;
-    int my_major, my_minor, my_micro;
-    int rq_major, rq_minor, rq_micro;
-    const char *my_plvl, *rq_plvl;
+	const char *ver = VERSION;
+	int my_major, my_minor, my_micro;
+	int rq_major, rq_minor, rq_micro;
+	const char *my_plvl, *rq_plvl;
 
-    if ( !req_version )
-	return ver;
+	if (!req_version)
+		return ver;
 
-    my_plvl = parse_version_string( ver, &my_major, &my_minor, &my_micro );
-    if ( !my_plvl )
-	return NULL;  /* very strange our own version is bogus */
-    rq_plvl = parse_version_string( req_version, &rq_major, &rq_minor,
-								&rq_micro );
-    if ( !rq_plvl )
-	return NULL;  /* req version string is invalid */
+	my_plvl =
+	    parse_version_string(ver, &my_major, &my_minor, &my_micro);
+	if (!my_plvl)
+		return NULL;	/* very strange our own version is bogus */
+	rq_plvl = parse_version_string(req_version, &rq_major, &rq_minor,
+				       &rq_micro);
+	if (!rq_plvl)
+		return NULL;	/* req version string is invalid */
 
-    if ( my_major > rq_major
-	|| (my_major == rq_major && my_minor > rq_minor)
-	|| (my_major == rq_major && my_minor == rq_minor
-				 && my_micro > rq_micro)
-	|| (my_major == rq_major && my_minor == rq_minor
-				 && my_micro == rq_micro
-				 && strcmp( my_plvl, rq_plvl ) >= 0) ) {
-	return ver;
-    }
-    return NULL;
+	if (my_major > rq_major
+	    || (my_major == rq_major && my_minor > rq_minor)
+	    || (my_major == rq_major && my_minor == rq_minor
+		&& my_micro > rq_micro)
+	    || (my_major == rq_major && my_minor == rq_minor
+		&& my_micro == rq_micro
+		&& strcmp(my_plvl, rq_plvl) >= 0)) {
+		return ver;
+	}
+	return NULL;
 }
-
