@@ -22,7 +22,8 @@
 #include <libdefs.h>
 #endif
 
-#ifdef USE_LTDL
+#ifdef DLMUTEX
+
 static void _mcrypt_mutex_seterror (const char *ERROR) {
  return; /* do nothing */
 }
@@ -31,7 +32,6 @@ static const char * _mcrypt_mutex_geterror (void) {
  return NULL;
 }
 
-# ifndef NO_DLMUTEX
 WIN32DLL_DEFINE
 int mcrypt_mutex_register ( void (*mutex_lock)(void) , 
 			void (*mutex_unlock)(void)) 
@@ -41,12 +41,11 @@ int mcrypt_mutex_register ( void (*mutex_lock)(void) ,
 		_mcrypt_mutex_seterror, _mcrypt_mutex_geterror);
 
 }
-# else
+#else
 WIN32DLL_DEFINE
 int mcrypt_mutex_register ( void (*mutex_lock)(void) ,
                         void (*mutex_unlock)(void))   
                         {
                         return 0;
 }
-# endif /* NO_DLMUTEX */
-#endif
+#endif /* NO_DLMUTEX */
