@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rc2.c,v 1.13 2002/10/01 11:26:47 nmav Exp $ */
+/* $Id: rc2.c,v 1.14 2003/01/19 17:48:27 nmav Exp $ */
 
 #include <libdefs.h>
 
@@ -314,8 +314,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 }
 
 #ifdef WIN32
+# ifdef USE_LTDL
 WIN32DLL_DEFINE int main (void)
 {
        /* empty main function to avoid linker error (see cygwin FAQ) */
 }
+# endif
 #endif
