@@ -21,7 +21,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: safer64.c,v 1.11 2002/10/01 11:26:47 nmav Exp $ */
+/* $Id: safer64.c,v 1.12 2003/01/19 17:48:27 nmav Exp $ */
 
 /******************* External Headers *****************************************/
 
@@ -385,8 +385,10 @@ WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 }
 
 #ifdef WIN32
+# ifdef USE_LTDL
 WIN32DLL_DEFINE int main (void)
 {
        /* empty main function to avoid linker error (see cygwin FAQ) */
 }
+# endif
 #endif
