@@ -1,5 +1,5 @@
 typedef struct saferplus_instance {
-  word8 l_key[33*16];
+  byte l_key[33*16];
   word32 k_bytes;
 } SPI;
 
