@@ -1,8 +1,10 @@
 typedef struct wake_key {
-	word32 k[4];
 	word32 t[257];
 	word32 r[4];
 	int counter;
-	word32 input_buffer;
+	word32 tmp; /* used as r1 or r2 */
+	int started;
+	word32 iv[8];
+	int ivsize;
 } WAKE_KEY;
 
