@@ -241,8 +241,10 @@ word32 _mcrypt_mode_version() {
 }
 
 #ifdef WIN32
+# ifdef USE_LTDL
 WIN32DLL_DEFINE int main (void)
 {
        /* empty main function to avoid linker error (see cygwin FAQ) */
 }
+# endif
 #endif
